Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(217)

Unified Diff: third_party/WebKit/Source/core/editing/iterators/TextIterator.cpp

Issue 2508743002: Changed EWhiteSpace to an enum class and renamed its members to keywords (Closed)
Patch Set: Small mac fix Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/dom/Text.cpp ('k') | third_party/WebKit/Source/core/layout/LayoutBlock.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/editing/iterators/TextIterator.cpp
diff --git a/third_party/WebKit/Source/core/editing/iterators/TextIterator.cpp b/third_party/WebKit/Source/core/editing/iterators/TextIterator.cpp
index b5d8296d4369f32e387dba80b788c6b6c19bd129..e41d636c3b389a8310cc416f33e2f6fc4a06417d 100644
--- a/third_party/WebKit/Source/core/editing/iterators/TextIterator.cpp
+++ b/third_party/WebKit/Source/core/editing/iterators/TextIterator.cpp
@@ -713,9 +713,9 @@ void TextIteratorAlgorithm<Strategy>::handleTextBox() {
// This effectively translates newlines to spaces without copying the
// text.
if (str[runStart] == '\n') {
// We need to preserve new lines in case of PRE_LINE.
// See bug crbug.com/317365.
- if (layoutObject->style()->whiteSpace() == PRE_LINE)
+ if (layoutObject->style()->whiteSpace() == EWhiteSpace::PreLine)
spliceBuffer('\n', m_node, 0, runStart, runStart);
else
spliceBuffer(spaceCharacter, m_node, 0, runStart, runStart + 1);
@@ -713,9 +713,9 @@ void TextIteratorAlgorithm<Strategy>::handleTextBox() {
// text.
if (str[runStart] == '\n') {
- // We need to preserve new lines in case of PRE_LINE.
+ // We need to preserve new lines in case of PreLine.
// See bug crbug.com/317365.
« no previous file with comments | « third_party/WebKit/Source/core/dom/Text.cpp ('k') | third_party/WebKit/Source/core/layout/LayoutBlock.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698